@@ -35,10 +35,10 @@ import ldap
 import os
 
 
-def userExists(username):
-	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
-	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
-	dbName = hubzero.config.webconfig.getWebConfigDBName()
+def userExists(username, hubname = ""):
+	dbPW = hubzero.config.webconfig.getWebConfigDBPassword(hubname)
+	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername(hubname)
+	dbName = hubzero.config.webconfig.getWebConfigDBName(hubname)
 	
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 	if _userExists(db, username):
@@ -55,10 +55,10 @@ def _userExists(db, username):
 	return userID
 
 
-def userLookup(username):
-	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
-	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
-	dbName = hubzero.config.webconfig.getWebConfigDBName()
+def userLookup(username, hubname = ""):
+	dbPW = hubzero.config.webconfig.getWebConfigDBPassword(hubname)
+	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername(hubname)
+	dbName = hubzero.config.webconfig.getWebConfigDBName(hubname)
 	
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 	rv = _userExists(db, username)
@@ -215,13 +215,13 @@ def _insert_jos_users_password(db, userid, pw):
 	db.query_rowcount(sql, data)
 
 
-def add_ldap_user(username, gecos, password, uidNumber, homeDir, loginShell, gid, gidNumber):
+def add_ldap_user(username, gecos, password, uidNumber, homeDir, loginShell, gid, gidNumber, hubname = ""):
 
 	# get ldapManagerUserDN and PW
 	
-	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
-	hubLDAPAcctMgrPW= hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
-	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")	
+	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn", hubname)
+	hubLDAPAcctMgrPW= hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw", hubname)
+	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn", hubname)	
 
 	l = ldap.open("localhost")
 	l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
@@ -254,11 +254,11 @@ def add_ldap_user(username, gecos, password, uidNumber, homeDir, loginShell, gid
 	l.add_s(dn, ldif)
 
 
-def delete_ldap_user(username):
+def delete_ldap_user(username, hubname = ""):
 	# get ldapManagerUserDN and PW
-	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
-	hubLDAPAcctMgrPW= hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
-	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")	
+	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn", hubname)
+	hubLDAPAcctMgrPW= hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw", hubname)
+	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn", hubname)	
 
 	l = ldap.open("localhost")
 	l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
@@ -291,9 +291,9 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
 	"""
 
 	# grab config options
-	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
-	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
-	dbName = hubzero.config.webconfig.getWebConfigDBName()
+	dbPW = hubzero.config.webconfig.getWebConfigDBPassword(hubname)
+	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername(hubname)
+	dbName = hubzero.config.webconfig.getWebConfigDBName(hubname)
 	
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 
@@ -396,10 +396,10 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
 	return(0)
 
 	
-def delhubuser(username):
-	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
-	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
-	dbName = hubzero.config.webconfig.getWebConfigDBName()
+def delhubuser(username, hubname = ""):
+	dbPW = hubzero.config.webconfig.getWebConfigDBPassword(hubname)
+	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername(hubname)
+	dbName = hubzero.config.webconfig.getWebConfigDBName(hubname)
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 	
 	sql = 'select id from `jos_users` where username = %s'
@@ -416,14 +416,14 @@ def delhubuser(username):
 	delete_ldap_user(username)
 
 
-def updateUserPW(username, pw, updateCMS = True, updateLDAP = True):
+def updateUserPW(username, pw, updateCMS = True, updateLDAP = True, hubname = ""):
 	"""
 	pass plaintext pw, we'll hash it
 	"""
 
-	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
-	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
-	dbName = hubzero.config.webconfig.getWebConfigDBName()
+	dbPW = hubzero.config.webconfig.getWebConfigDBPassword(hubname)
+	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername(hubname)
+	dbName = hubzero.config.webconfig.getWebConfigDBName(hubname)
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 
 	userid = _getUserID(db, username)
@@ -438,14 +438,14 @@ def updateUserPW(username, pw, updateCMS = True, updateLDAP = True):
 		_update_ldap_user_pw(username, userid, pw)
 	
 
-def uidNumberExists(uidNumber):
+def uidNumberExists(uidNumber, hubname = ""):
 	"""
 	See if specified uidNumber is in the ldap user ou
 	"""
 
-	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
-	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
-	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")	
+	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn", hubname)
+	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw", hubname)
+	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn", hubname)	
 
 	l = ldap.open("localhost")
 	l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
@@ -458,14 +458,14 @@ def uidNumberExists(uidNumber):
 		return True
 
 
-def uidExists(uid):
+def uidExists(uid, hubname = ""):
 	"""
 	See if specified uid is in the ldap user ou
 	"""
 
-	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
-	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
-	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")	
+	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn", hubname)
+	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw", hubname)
+	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn", hubname)	
 
 	l = ldap.open("localhost")
 	l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
@@ -478,14 +478,14 @@ def uidExists(uid):
 		return True
 	
 	
-def getLDAPMaxuid():
+def getLDAPMaxuid(hubname = ""):
 	"""
 	get max(uid) of all objects of class posixAccount in ou=Users
 	"""
 
-	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
-	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
-	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")	
+	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn", hubname)
+	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw", hubname)
+	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn", hubname)	
 
 	l = ldap.open("localhost")
 	l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
@@ -499,4 +499,4 @@ def getLDAPMaxuid():
 		x = int(result[1]['uidNumber'][0])
 		if x > maxid: maxid = x
 		
-	return maxid	
\ No newline at end of file
+	return maxid	
